aboutsummaryrefslogtreecommitdiff
path: root/bootstrap
blob: de024aeaa5c225b5dc0dbea32d53d9b845ed9279 (about) (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
#!/bin/sh
# Create the build system.

set -e -x

# Generate stubs for translations.
langs=`find po/doc -type f -name 'guix-manual*.po' \
        | sed -e 's,.*/guix-manual\.,,;s,\.po$,,'`
for lang in ${langs}; do
    if [ ! -e "doc/guix.${lang}.texi" ]; then
	echo "@setfilename guix.${lang}.info" > "doc/guix.${lang}.texi"
	echo "@include version-${lang}.texi" >> "doc/guix.${lang}.texi"
	# Ensure .po file is newer.
	touch "po/doc/guix-manual.${lang}.po"
    fi
done
langs=`find po/doc -type f -name 'guix-cookbook*.po' \
        | sed -e 's,.*/guix-cookbook\.,,;s,\.po$,,'`
for lang in ${langs}; do
    if [ ! -e "doc/guix-cookbook.${lang}.texi" ]; then
	echo "@setfilename guix-cookbook.${lang}.info" > "doc/guix-cookbook.${lang}.texi"
	# Ensure .po file is newer.
	touch "po/doc/guix-cookbook.${lang}.po"
    fi
done

exec autoreconf -vfi
1d9b38c6590170a628dc67283f0784e1dd0'>diff)downloadguix-6bf4939ebf89878dfca0837983e527a4d80ba382.tar.gz
guix-6bf4939ebf89878dfca0837983e527a4d80ba382.zip
gnu: lxcfs: Use G-expressions.
* gnu/packages/virtualization.scm (lxcfs)[arguments]: Rewrite as G-expressions.
Diffstat (limited to 'gnu')
-rw-r--r--gnu/packages/virtualization.scm16
1 files changed, 9 insertions, 7 deletions
diff --git a/gnu/packages/virtualization.scm b/gnu/packages/virtualization.scm
index 1eacdcc2fe..018a402605 100644
--- a/gnu/packages/virtualization.scm
+++ b/gnu/packages/virtualization.scm
@@ -1321,13 +1321,15 @@ manage system or application containers.")
(base32
"02cgzh97cgxh9iyf7gkn5ikdc0sfzqfjj6al0hikdf9rbwcscqwd"))))
(arguments
- '(#:configure-flags '("--localstatedir=/var")
- #:phases
- (modify-phases %standard-phases
- (replace 'bootstrap
- ;; Work around missing interpreter shebang.
- (lambda _
- (invoke "bash" "bootstrap.sh"))))))
+ (list
+ #:configure-flags
+ #~(list "--localstatedir=/var")
+ #:phases
+ #~(modify-phases %standard-phases
+ (replace 'bootstrap
+ ;; Work around missing interpreter shebang.
+ (lambda _
+ (invoke "bash" "bootstrap.sh"))))))
(native-inputs
(list autoconf automake libtool pkg-config))
(inputs